@@ -8,8 +8,11 @@ import loguru
 from apscheduler.executors.asyncio import AsyncIOExecutor
 from apscheduler.triggers.interval import IntervalTrigger
 from pydantic import BaseModel
-from sanic import json
+from sanic import json, Sanic
+from sanic_ext.extensions.openapi.blueprint import blueprint_factory
+from sanic_ext.extensions.openapi.builders import SpecificationBuilder
 from tortoise import fields
+from json import dump
 
 from web_foundation import settings
 from web_foundation.config import DbConfig, AppConf
@@ -79,6 +82,16 @@ if __name__ == '__main__':
     scheduler = TaskScheduler(executors={"default": AsyncIOExecutor()})
     dispatcher = IDispatcher(scheduler=scheduler)
     app = App(dependency_container=container, dispatcher=dispatcher)
+
+    async def generate_openapi(s_app: Sanic):
+
+        oas_json = SpecificationBuilder().build(s_app).serialize()
+        with open("openapi.json", 'w') as f:
+            dump(oas_json, f)
+
+    app.sanic.after_server_start(generate_openapi)
+
+
     # app.sanic.config.HEALTH = True
     # app.sanic.config.HEALTH_ENDPOINT = True
     async def check_add(s_app, *args, **kwargs):
