@@ -2,7 +2,8 @@ from typing import TypeVar, Dict, Generic
 
 from apscheduler.triggers.base import BaseTrigger
 
-from web_foundation.extentions.schedulle.scheduller import TaskIMessage, BackgroundTask, TaskErrorCallback
+from web_foundation.extentions.schedulle.scheduller import TaskIMessage, BackgroundTask, TaskErrorCallback, \
+    TaskCompleteCallback
 from web_foundation.kernel.container import GenericDependencyContainer
 from web_foundation.kernel.messaging.channel import IMessage, IChannel
 
@@ -15,12 +16,14 @@ class Service(Generic[GenericDependencyContainer]):
                              *args,
                              trigger: BaseTrigger = None,
                              on_error_callback: TaskErrorCallback = None,
+                             on_complete_callback: TaskCompleteCallback = None,
                              add_job_kw: Dict = None, return_event: bool = False, **kwargs,
                              ):
         await self.emmit_event(
             TaskIMessage(task,
                          trigger,
                          on_error_callback=on_error_callback,
+                         on_complete_callback=on_complete_callback,
                          add_job_kw=add_job_kw,
                          args=args,
                          kwargs=kwargs,
