@@ -1,15 +1,9 @@
 from abc import ABCMeta
-from typing import Any
+from typing import Any, Generic, TypeVar
 
-from web_foundation.resources.resource import Resource
-
-
-class FilesResource(Resource, metaclass=ABCMeta):
+class FilesResourceInterface(metaclass=ABCMeta):
     root: Any
 
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-
     async def open(self, path: Any, *args, **kwargs) -> Any:
         raise NotImplementedError
 
