@@ -108,6 +108,15 @@ def in_obj_subclasses(obj: object | Type, target_cls: Type):
         raise e
 
 
+def is_in_base_classes(obj: object | Type, target_cls: Type) -> bool:
+    try:
+        if obj.__class__ == target_cls:
+            return True
+        return target_cls in obj.__class__.__mro__
+    except Exception as e:
+        raise e
+
+
 def in_obj_subcls_of_dependencies(obj: object | Type, target_cls: Type):
     try:
         for i in dir(obj):
